==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/accessdiversity/accessdiversity/constraints/constraint/target/targetflavor/DefaultAllGroups.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.accessdiversity.accessdiversity.constraints.constraint.target.targetflavor;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.accessdiversity.accessdiversity.constraints.constraint.target.TargetFlavor;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of allGroups.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAllGroups extends InnerModelObject implements AllGroups {
    protected boolean allOtherGroups;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public boolean allOtherGroups() {
        return allOtherGroups;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void allOtherGroups(boolean allOtherGroups) {
        valueLeafFlags.set(LeafIdentifier.ALLOTHERGROUPS.getLeafIndex());
        this.allOtherGroups = allOtherGroups;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allOtherGroups, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAllGroups) {
            DefaultAllGroups other = (DefaultAllGroups) obj;
            return
                Objects.equals(allOtherGroups, other.allOtherGroups) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("allOtherGroups=" + allOtherGroups)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultAllGroups.
     */
    public DefaultAllGroups() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/accessdiversity/accessdiversity/constraints/constraint/target/targetflavor/DefaultAllGroups.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.accessdiversity.accessdiversity.constraints.constraint.target.targetflavor;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.accessdiversity.accessdiversity.constraints.constraint.target.TargetFlavor;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of allGroups.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAllGroups extends InnerModelObject implements AllGroups {
    protected boolean allOtherGroups;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public boolean allOtherGroups() {
        return allOtherGroups;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void allOtherGroups(boolean allOtherGroups) {
        valueLeafFlags.set(LeafIdentifier.ALLOTHERGROUPS.getLeafIndex());
        this.allOtherGroups = allOtherGroups;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allOtherGroups, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAllGroups) {
            DefaultAllGroups other = (DefaultAllGroups) obj;
            return
                Objects.deepEquals(allOtherGroups, other.allOtherGroups) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("allOtherGroups=" + allOtherGroups)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultAllGroups.
     */
    public DefaultAllGroups() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
